@@ -16,7 +16,7 @@
 
 
 import os
-from urlparse import urlparse
+from urllib.parse import urlparse
 import tempfile
 
 import gi
@@ -41,7 +41,7 @@ def soup_status_is_successful(status):
 def get_soup_session():
     global _session
     if _session is None:
-        _session = Soup.SessionAsync()
+        _session = Soup.Session()
         _session.set_property("timeout", 60)
         _session.set_property("idle-timeout", 60)
         _session.set_property("user-agent", "Sugar/%s" % config.version)
@@ -81,7 +81,7 @@ class Downloader(GObject.GObject):
         self._message.connect('got-chunk', self._got_chunk_cb)
         self._message.connect('got-headers', self._headers_cb, None)
         if self._request_headers is not None:
-            for header_key in self._request_headers.keys():
+            for header_key in list(self._request_headers.keys()):
                 self._message.request_headers.append(
                     header_key, self._request_headers[header_key])
 
